==> haskell-microlens-aeson-2.2.0.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.2.0.1
id: microlens-aeson-2.2.0.1-HIeqNx2Wtq385ormgkViI0
key: microlens-aeson-2.2.0.1-HIeqNx2Wtq385ormgkViI0
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
           Copyright (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
stability: provisional
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
author: Colin Woodbury
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal
abi: e8aee438fc50a8912baddbd27d2c730d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-aeson-2.2.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-aeson-2.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/microlens-aeson-2.2.0.1
hs-libraries: HSmicrolens-aeson-2.2.0.1-HIeqNx2Wtq385ormgkViI0
depends:
    aeson-1.1.2.0-8R262j8BseM7FTnCfGfbwu
    attoparsec-0.13.2.0-JkqjYPxw7sG9Iq2J4E1Ndn base-4.9.1.0
    bytestring-0.10.8.1 microlens-0.4.8.0-5PXN9DedWooJg6UJ24ter0
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.2.0.1-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-aeson
version: 2.2.0.1
id: microlens-aeson-2.2.0.1-3BsNGmmtpoyB4pxxQ1gYH6
key: microlens-aeson-2.2.0.1-3BsNGmmtpoyB4pxxQ1gYH6
license: MIT
copyright: Copyright (C) 2012 Paul Wilson
           Copyright (C) 2013 Edward A. Kmett
           Copyright (C) 2015 Colin Woodbury
maintainer: Colin Woodbury <colingw@gmail.com>
stability: provisional
homepage: http://github.com/fosskers/microlens-aeson/
synopsis: Law-abiding lenses for Aeson, using microlens.
description:
    Law-abiding lenses for Aeson, using microlens.
category: Numeric
author: Colin Woodbury
exposed: True
exposed-modules:
    Lens.Micro.Aeson
hidden-modules: Lens.Micro.Aeson.Internal
abi: 0df297cfa7e132a073a84d6d2e3b98a9
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-aeson-2.2.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-aeson-2.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/microlens-aeson-2.2.0.1
hs-libraries: HSmicrolens-aeson-2.2.0.1-3BsNGmmtpoyB4pxxQ1gYH6
depends:
    aeson-1.1.2.0-8R262j8BseM7FTnCfGfbwu
    attoparsec-0.13.2.0-JkqjYPxw7sG9Iq2J4E1Ndn base-4.9.1.0
    bytestring-0.10.8.1 microlens-0.4.8.1-BVhsezHoPw9Ez18LAXVtpM
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock
haddock-html: /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
